Index: src/mips/simulator-mips.cc |
diff --git a/src/mips/simulator-mips.cc b/src/mips/simulator-mips.cc |
index a158f045f50764f6fd2a87b85a02d207d015ed5d..f31ce7ea48a117437b3acb1b01ed4dbc76049427 100644 |
--- a/src/mips/simulator-mips.cc |
+++ b/src/mips/simulator-mips.cc |
@@ -1369,9 +1369,9 @@ void Simulator::WriteB(int32_t addr, int8_t value) { |
// Returns the limit of the stack area to enable checking for stack overflows. |
uintptr_t Simulator::StackLimit() const { |
// Leave a safety margin of 512 bytes to prevent overrunning the stack when |
// pushing values. |
- return reinterpret_cast<uintptr_t>(stack_) + 512; |
+ return reinterpret_cast<uintptr_t>(stack_) + 1024; |
} |
@@ -1369,9 +1369,9 @@ void Simulator::WriteB(int32_t addr, int8_t value) { |
// Returns the limit of the stack area to enable checking for stack overflows. |
uintptr_t Simulator::StackLimit() const { |
- // Leave a safety margin of 512 bytes to prevent overrunning the stack when |
+ // Leave a safety margin of 1024 bytes to prevent overrunning the stack when |
// pushing values. |